==> haskell-drbg-0.5.5-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-BYZx7ayILp6C3K10Mg4u5H
key: DRBG-0.5.5-BYZx7ayILp6C3K10Mg4u5H
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: de31e22480e0ac9dd0eb981d938166a3
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-BYZx7ayILp6C3K10Mg4u5H
depends:
    base-4.11.1.0 cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    bytestring-0.10.8.2 prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
    cryptohash-cryptoapi-0.1.4-rjxXt9DV606KD7gGWhtvv
    parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS mtl-2.2.2
    cipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI=942d5299484d2a2b1e170c366961bcd8
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             cryptohash-cryptoapi-0.1.4-rjxXt9DV606KD7gGWhtvv=195394bf479069b5f5b587a55cbcbd1b
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=bfa6d2c22d7e7c439a84add8c91d8e7a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             cipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P=bf2a1d9215074c4c7b0825b7b3d257db
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-5XwMpXzWfXwDNpWHbxZBlO
key: DRBG-0.5.5-5XwMpXzWfXwDNpWHbxZBlO
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: e04a9ec3e99e58759b5e529f30cd5e7d
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-5XwMpXzWfXwDNpWHbxZBlO
depends:
    base-4.11.1.0 cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    bytestring-0.10.8.2 prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
    cryptohash-cryptoapi-0.1.4-rjxXt9DV606KD7gGWhtvv
    parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS mtl-2.2.2
    cipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI=942d5299484d2a2b1e170c366961bcd8
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             cryptohash-cryptoapi-0.1.4-rjxXt9DV606KD7gGWhtvv=195394bf479069b5f5b587a55cbcbd1b
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=bfa6d2c22d7e7c439a84add8c91d8e7a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             cipher-aes128-0.7.0.3-KZRh36IRPZaDi32G4X425P=bf2a1d9215074c4c7b0825b7b3d257db
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
